@@ -112,13 +112,13 @@ CrontabWidget::CrontabWidget(QWidget* parent, CTHost* ctHost) :
 
 	initialize();
 
-	logDebug() << "Clipboard Status " << hasClipboardContent() << endl;
+	logDebug() << "Clipboard Status " << hasClipboardContent();
 
 	d->tasksWidget->setFocus();
 
 	QTreeWidgetItem* item = d->tasksWidget->treeWidget()->topLevelItem(0);
 	if (item != nullptr) {
-		logDebug() << "First item found" << d->tasksWidget->treeWidget()->topLevelItemCount() << endl;
+		logDebug() << "First item found" << d->tasksWidget->treeWidget()->topLevelItemCount();
 		item->setSelected(true);
 	}
 
@@ -192,7 +192,11 @@ QHBoxLayout* CrontabWidget::createCronSelector() {
 	}
 
 	connect(group, static_cast<void (QButtonGroup::*)(QAbstractButton *)>(&QButtonGroup::buttonClicked), this, &CrontabWidget::refreshCron);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
 	connect(d->otherUsers, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &CrontabWidget::checkOtherUsers);
+#else
+	connect(d->otherUsers, static_cast<void (QComboBox::*)(int, const QString &)>(&QComboBox::currentIndexChanged) , this, &CrontabWidget::checkOtherUsers);
+#endif
 
 	layout->addStretch(1);
 
@@ -202,9 +206,9 @@ QHBoxLayout* CrontabWidget::createCronSelector() {
 void CrontabWidget::initialize() {
 	QVBoxLayout* layout = new QVBoxLayout(this);
 
-	logDebug() << "Begin view refresh" << endl;
+	logDebug() << "Begin view refresh";
 
-	logDebug() << "Creating Tasks list..." << endl;
+	logDebug() << "Creating Tasks list...";
 
 	QHBoxLayout* cronSelector = createCronSelector();
 	layout->addLayout(cronSelector);
@@ -233,7 +237,7 @@ void CrontabWidget::refreshCron() {
 	d->variablesWidget->refreshVariables(ctCron);
 
 	if (ctCron->isMultiUserCron() && ctHost()->isRootUser()==false) {
-		logDebug() << "Disabling view..." << endl;
+		logDebug() << "Disabling view...";
 
 		d->tasksWidget->treeWidget()->setEnabled(false);
 		d->variablesWidget->treeWidget()->setEnabled(false);
@@ -244,7 +248,7 @@ void CrontabWidget::refreshCron() {
 		d->tasksWidget->toggleRunNowAction(false);
 	}
 	else {
-		logDebug() << "Enabling view..." << endl;
+		logDebug() << "Enabling view...";
 
 		d->tasksWidget->treeWidget()->setEnabled(true);
 		d->variablesWidget->treeWidget()->setEnabled(true);
@@ -269,7 +273,7 @@ void CrontabWidget::copy() {
 	QString clipboardText;
 
 	if (d->tasksWidget->treeWidget()->hasFocus()) {
-		logDebug() << "Tasks copying" << endl;
+		logDebug() << "Tasks copying";
 
 		QList<TaskWidget*> tasksWidget = d->tasksWidget->selectedTasksWidget();
 		foreach(TaskWidget* taskWidget, tasksWidget) {
@@ -281,7 +285,7 @@ void CrontabWidget::copy() {
 	}
 
 	if (d->variablesWidget->treeWidget()->hasFocus()) {
-		logDebug() << "Variables copying" << endl;
+		logDebug() << "Variables copying";
 
 		QList<VariableWidget*> variablesWidget = d->variablesWidget->selectedVariablesWidget();
 		foreach(VariableWidget* variableWidget, variablesWidget) {
@@ -295,28 +299,28 @@ void CrontabWidget::copy() {
 	QApplication::clipboard()->setText(clipboardText, QClipboard::Clipboard);
 	QApplication::clipboard()->setText(clipboardText, QClipboard::Selection);
 
-	logDebug() << "Clipboard Status " << hasClipboardContent() << endl;
+	logDebug() << "Clipboard Status " << hasClipboardContent();
 	togglePasteAction(hasClipboardContent());
 }
 
 void CrontabWidget::cut() {
-	logDebug() << "Cut content" << endl;
+	logDebug() << "Cut content";
 
 	copy();
 
 	if (d->tasksWidget->treeWidget()->hasFocus()) {
-		logDebug() << "Tasks cutting" << endl;
+		logDebug() << "Tasks cutting";
 		d->tasksWidget->deleteSelection();
 	}
 
 	if (d->variablesWidget->treeWidget()->hasFocus()) {
-		logDebug() << "Variables cutting" << endl;
+		logDebug() << "Variables cutting";
 		d->variablesWidget->deleteSelection();
 	}
 }
 
 void CrontabWidget::paste() {
-	logDebug() << "Paste content" << endl;
+	logDebug() << "Paste content";
 
 	if (d->tasksWidget->treeWidget()->hasFocus()) {
 		foreach(CTTask* task, d->clipboardTasks) {
@@ -339,7 +343,7 @@ CTCron* CrontabWidget::currentCron() const {
 		return d->ctHost->findSystemCron();
 
 	if (d->otherUsers->currentIndex() == d->otherUsers->count()-1) {
-		logDebug() << "Using Global Cron" << endl;
+		logDebug() << "Using Global Cron";
 		return d->ctGlobalCron;
 	}
 
@@ -366,7 +370,7 @@ void CrontabWidget::checkOtherUsers() {
 }
 
 void CrontabWidget::setupActions() {
-	logDebug() << "Setup actions" << endl;
+	logDebug() << "Setup actions";
 
 	//Edit menu
 	d->cutAction = KStandardAction::cut(this, SLOT(cut()), this);
@@ -374,7 +378,7 @@ void CrontabWidget::setupActions() {
 	d->pasteAction = KStandardAction::paste(this, SLOT(paste()), this);
 	togglePasteAction(false);
 
-	logDebug() << "Actions initialized" << endl;
+	logDebug() << "Actions initialized";
 
 }
 
@@ -410,7 +414,7 @@ void CrontabWidget::print() {
 	CrontabPrinter printer(this);
 
 	if (printer.start() == false) {
-		logDebug() << "Unable to start printer" << endl;
+		logDebug() << "Unable to start printer";
 		return;
 	}
 	printer.printTasks();
